@@ -162,6 +162,12 @@ class Function(object):
 
         return self._blocks
 
+    @property
+    def uuid(self):
+        """Gets the UUID for the function."""
+
+        return self._uuid
+
     def __repr__(self):
         def block_addr(x):
             return x.byte_interval.address + x.offset
